#' @keywords internal
"_PACKAGE"

#' @importFrom checkmate qassert assert_disjunct assert_choice assert_true
#' @importFrom checkmate test_class check_class assert
#' @importFrom data.table copy setDT fifelse fcase :=  %like% %between%
#' @importFrom settings options_manager stop_if_reserved reset
#' @importFrom units as_units deparse_unit
#' @importFrom wrapr stop_if_dot_args %?%
#'
NULL
